# Changelog

## [1.4.0](https://github.com/INiNiDS/aam-rs/compare/v1.3.3...v1.4.0) (2026-03-12)


### Features

* Add Python bindings and update CI workflow for packaging ([d5035e6](https://github.com/INiNiDS/aam-rs/commit/d5035e67dae6956bbe4f078a5c354e4cf9920778))


### Bug Fixes

* Fixed deny.toml ([3eb10d3](https://github.com/INiNiDS/aam-rs/commit/3eb10d30a99877ec1c1522f7967330e426a20807))

## [1.3.3](https://github.com/INiNiDS/aam-rs/compare/v1.3.2...v1.3.3) (2026-03-11)


### Bug Fixes

* Add C examples demonstrating aam-rs API usage and configuration loading ([258af0b](https://github.com/INiNiDS/aam-rs/commit/258af0b5258e0475c9f3eb08f50b490ecfbd6879))

## [1.3.2](https://github.com/INiNiDS/aam-rs/compare/v1.3.1...v1.3.2) (2026-03-11)


### Bug Fixes

* Deleted unnecessary file ([ac64d9a](https://github.com/INiNiDS/aam-rs/commit/ac64d9a5cbb798485aaaf157e59fde83325b4acf))

## [1.3.1](https://github.com/INiNiDS/aam-rs/compare/v1.3.0...v1.3.1) (2026-03-11)


### Bug Fixes

* Run Release please ([2eb686a](https://github.com/INiNiDS/aam-rs/commit/2eb686ae94a9deb511ce46bf44db48892bce8ce1))

## [1.3.0](https://github.com/INiNiDS/aam-rs/compare/v1.2.4...v1.3.0) (2026-03-11)


### Features

* Added C support ([57b8f92](https://github.com/INiNiDS/aam-rs/commit/57b8f927f10b103d008a2df39673f9bddeea96df))
